@@ -5,10 +5,12 @@ from files_sdk.exceptions import InvalidParameterError, MissingParameterError, N
 
 class ExternalEvent:
     default_attributes = {
+        'id': None,     # int64 - Event ID
         'event_type': None,     # string - Type of event being recorded.
         'status': None,     # string - Status of event.
         'body': None,     # string - Event body
         'created_at': None,     # date-time - External event create date/time
+        'body_url': None,     # string - Link to log file.
     }
 
     def __init__(self, attributes=None, options=None):
@@ -65,5 +67,23 @@ def list(params = None, options = None):
 def all(params = None, options = None):
     list(params, options)
 
+# Parameters:
+#   id (required) - int64 - External Event ID.
+def find(id, params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
+    params["id"] = id
+    if "id" in params and not isinstance(params["id"], int):
+        raise InvalidParameterError("Bad parameter: id must be an int")
+    if "id" not in params:
+        raise MissingParameterError("Parameter missing: id")
+    response, options = Api.send_request("GET", "/external_events/{id}".format(id=params['id']), params, options)
+    return ExternalEvent(response.data, options)
+
+def get(id, params = None, options = None):
+    find(id, params, options)
+
 def new(*args, **kwargs):
     return ExternalEvent(*args, **kwargs)
\ No newline at end of file
